Crate astarte_message_hub_proto

Crate astarte_message_hub_proto 

Astarte message hub protocol buffers for Rust

This module provides access to the Astarte message hub protocol buffers through a Rust API.

Documentation

Requirements

  • protobuf >= 3.15
  • Rust version >= 1.85

Client Example

You can find an example of a Message Hub client in the examples directory.

Re-exports

pub use prost;
pub use prost_types;
pub use serde;
pub use serde_json;
pub use tonic;

Modules

astarte_data
Nested message and enum types in AstarteData.
astarte_message
Nested message and enum types in AstarteMessage.
message_hub_client
Generated client implementations.
message_hub_config_client
Generated client implementations.
message_hub_config_server
Generated server implementations.
message_hub_event
Nested message and enum types in MessageHubEvent.
message_hub_server
Generated server implementations.

Structs

AstarteBinaryBlobArray
An array of bytes for transmission with protobuf. To be used nested inside an AstarteData.
AstarteBooleanArray
An array of booleans for transmission with protobuf. To be used nested inside an AstarteData.
AstarteData
A base Astarte data type for transmission with protobuf.
AstarteDatastreamIndividual
A datastream individual data type. To be used nested inside an AstarteMessage.
AstarteDatastreamObject
A datastream object data type. To be used nested inside an AstarteMessage.
AstarteDateTimeArray
An array of timestamps for transmission with protobuf. To be used nested inside an AstarteData.
AstarteDoubleArray
An array of doubles for transmission with protobuf. To be used nested inside an AstarteData.
AstarteIntegerArray
An array of int32 for transmission with protobuf. To be used nested inside an AstarteData.
AstarteLongIntegerArray
An array of int64 for transmission with protobuf. To be used nested inside an AstarteData.
AstarteMessage
Astarte message to be used when sending data to Astarte.
AstartePropertyIndividual
A property individual data type. To be used nested inside an AstarteMessage. It is also the structure returned by the GetProperty rpc.
AstarteStringArray
An array of strings for transmission with protobuf. To be used nested inside an AstarteData.
ConfigMessage
Configuration message to be used to send configuration to the Astarte message hub.
InterfaceName
This message is the request to the GetProperty rpc. it represents an Astarte interface name
InterfacesJson
This message defines a list of json interfaces to be added/removed to the Astarte message hub.
InterfacesName
This message defines a list of interfaces’ names to be removed from the Astarte message hub.
MessageHubError
MessageHub error type
MessageHubEvent
MessageHubEvent is a type of message for returning and propagating errors. It is an enum with the variants, AstarteMessage(message), representing success and containing an astarte message value, and MessageHubError(E) representing error and containing an error value.
Node
This message defines a node to be attached to the Astarte message hub.
Property
A message containing all the properties values and information associated to a given astarte interface.
PropertyFilter
This message is the request to the GetAllProperties rpc. If the ownership is not specified, all the interfaces are retrieved, both device and server owned. Otherwise, only the interfaces with the specified interfaces are retrieved.
PropertyIdentifier
This message is the request for a single property identified by interface name and path.
StoredProperties
This message is the response to the GetProperties rpc method.

Enums

Ownership
Enum representing an Astarte interface ownership.