Re-exports
pub use prost;pub use prost_types;pub use serde;pub use serde_json;pub use tonic;
Modules
- astarte_
data - Nested message and enum types in
AstarteData. - astarte_
message - Nested message and enum types in
AstarteMessage. - message_
hub_ client - Generated client implementations.
- message_
hub_ config_ client - Generated client implementations.
- message_
hub_ config_ server - Generated server implementations.
- message_
hub_ event - Nested message and enum types in
MessageHubEvent. - message_
hub_ server - Generated server implementations.
Structs
- Astarte
Binary Blob Array - An array of bytes for transmission with protobuf.
To be used nested inside an
AstarteData. - Astarte
Boolean Array - An array of booleans for transmission with protobuf.
To be used nested inside an
AstarteData. - Astarte
Data - A base Astarte data type for transmission with protobuf.
- Astarte
Datastream Individual - A datastream individual data type.
To be used nested inside an
AstarteMessage. - Astarte
Datastream Object - A datastream object data type.
To be used nested inside an
AstarteMessage. - Astarte
Date Time Array - An array of timestamps for transmission with protobuf.
To be used nested inside an
AstarteData. - Astarte
Double Array - An array of doubles for transmission with protobuf.
To be used nested inside an
AstarteData. - Astarte
Integer Array - An array of int32 for transmission with protobuf.
To be used nested inside an
AstarteData. - Astarte
Long Integer Array - An array of int64 for transmission with protobuf.
To be used nested inside an
AstarteData. - Astarte
Message - Astarte message to be used when sending data to Astarte.
- Astarte
Property Individual - A property individual data type.
To be used nested inside an
AstarteMessage. It is also the structure returned by theGetPropertyrpc. - Astarte
String Array - An array of strings for transmission with protobuf.
To be used nested inside an
AstarteData. - Config
Message - Configuration message to be used to send configuration to the Astarte message hub.
- Interface
Name - This message is the request to the GetProperty rpc. it represents an Astarte interface name
- Interfaces
Json - This message defines a list of json interfaces to be added/removed to the Astarte message hub.
- Interfaces
Name - This message defines a list of interfaces’ names to be removed from the Astarte message hub.
- Message
HubError - MessageHub error type
- Message
HubEvent - MessageHubEvent is a type of message for returning and propagating errors. It is an enum with the variants, AstarteMessage(message), representing success and containing an astarte message value, and MessageHubError(E) representing error and containing an error value.
- Node
- This message defines a node to be attached to the Astarte message hub.
- Property
- A message containing all the properties values and information associated to a given astarte interface.
- Property
Filter - This message is the request to the GetAllProperties rpc. If the ownership is not specified, all the interfaces are retrieved, both device and server owned. Otherwise, only the interfaces with the specified interfaces are retrieved.
- Property
Identifier - This message is the request for a single property identified by interface name and path.
- Stored
Properties - This message is the response to the GetProperties rpc method.
Enums
- Ownership
- Enum representing an Astarte interface ownership.